==> aws-android-sdk-ddb-2.2.18-sources.jar: com/amazonaws/services/dynamodbv2/model/transform/StreamSpecificationJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.dynamodbv2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.dynamodbv2.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * Stream Specification JSON Unmarshaller
 */
public class StreamSpecificationJsonUnmarshaller implements Unmarshaller<StreamSpecification, JsonUnmarshallerContext> {

    public StreamSpecification unmarshall(JsonUnmarshallerContext context) throws Exception {
        StreamSpecification streamSpecification = new StreamSpecification();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            
            if (name.equals("StreamEnabled")) {
                streamSpecification.setStreamEnabled(BooleanJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            if (name.equals("StreamViewType")) {
                streamSpecification.setStreamViewType(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            {
                reader.skipValue();
            }
            
        }
        reader.endObject();
        
        return streamSpecification;
    }

    private static StreamSpecificationJsonUnmarshaller instance;
    public static StreamSpecificationJsonUnmarshaller getInstance() {
        if (instance == null) instance = new StreamSpecificationJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-ddb-2.2.20-sources.jar: com/amazonaws/services/dynamodbv2/model/transform/StreamSpecificationJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.dynamodbv2.model.transform;

import com.amazonaws.services.dynamodbv2.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO StreamSpecification
 */
class StreamSpecificationJsonUnmarshaller implements
        Unmarshaller<StreamSpecification, JsonUnmarshallerContext> {

    public StreamSpecification unmarshall(JsonUnmarshallerContext context) throws Exception {
        StreamSpecification streamSpecification = new StreamSpecification();
        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("StreamEnabled")) {
                streamSpecification.setStreamEnabled(BooleanJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("StreamViewType")) {
                streamSpecification.setStreamViewType(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return streamSpecification;
    }

    private static StreamSpecificationJsonUnmarshaller instance;

    public static StreamSpecificationJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new StreamSpecificationJsonUnmarshaller();
        return instance;
    }
}
